summaryrefslogtreecommitdiffstats
path: root/arch/x86/include
diff options
context:
space:
mode:
authorDominik Brodowski <linux@dominikbrodowski.net>2018-04-09 12:51:42 +0200
committerIngo Molnar <mingo@kernel.org>2018-04-09 16:47:27 +0200
commite145242ea0df6b7d28fd7186e61d6840fa4bb06e (patch)
tree912d8a3641ebdd609ca99c0cbdee99e2f299b2f3 /arch/x86/include
parent6dc936f175cc6d12a8eb14d29b87e9238e460383 (diff)
downloadlinux-e145242ea0df6b7d28fd7186e61d6840fa4bb06e.tar.bz2
syscalls/core, syscalls/x86: Clean up syscall stub naming convention
Tidy the naming convention for compat syscall subs. Hints which describe the purpose of the stub go in front and receive a double underscore to denote that they are generated on-the-fly by the SYSCALL_DEFINEx() macro. For the generic case, this means (0xffffffff prefix removed): 810f08d0 t kernel_waitid # common C function (see kernel/exit.c) <inline> __do_sys_waitid # inlined helper doing the actual work # (takes original parameters as declared) 810f1aa0 T __se_sys_waitid # sign-extending C function calling inlined # helper (takes parameters of type long; # casts them to the declared type) 810f1aa0 T sys_waitid # alias to __se_sys_waitid() (taking # parameters as declared), to be included # in syscall table For x86, the naming is as follows: 810efc70 t kernel_waitid # common C function (see kernel/exit.c) <inline> __do_sys_waitid # inlined helper doing the actual work # (takes original parameters as declared) 810efd60 t __se_sys_waitid # sign-extending C function calling inlined # helper (takes parameters of type long; # casts them to the declared type) 810f1140 T __ia32_sys_waitid # IA32_EMULATION 32-bit-ptregs -> C stub, # calls __se_sys_waitid(); to be included # in syscall table 810f1110 T sys_waitid # x86 64-bit-ptregs -> C stub, calls # __se_sys_waitid(); to be included in # syscall table For x86, sys_waitid() will be re-named to __x64_sys_waitid in a follow-up patch. Suggested-by: Ingo Molnar <mingo@kernel.org> Signed-off-by: Dominik Brodowski <linux@dominikbrodowski.net> Cc: Al Viro <viro@zeniv.linux.org.uk> Cc: Andrew Morton <akpm@linux-foundation.org> Cc: Andy Lutomirski <luto@kernel.org> Cc: Borislav Petkov <bp@alien8.de> Cc: Brian Gerst <brgerst@gmail.com> Cc: Denys Vlasenko <dvlasenk@redhat.com> Cc: Josh Poimboeuf <jpoimboe@redhat.com> Cc: Linus Torvalds <torvalds@linux-foundation.org> Cc: Peter Zijlstra <peterz@infradead.org> Cc: Thomas Gleixner <tglx@linutronix.de> Link: http://lkml.kernel.org/r/20180409105145.5364-2-linux@dominikbrodowski.net Signed-off-by: Ingo Molnar <mingo@kernel.org>
Diffstat (limited to 'arch/x86/include')
-rw-r--r--arch/x86/include/asm/syscall_wrapper.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/arch/x86/include/asm/syscall_wrapper.h b/arch/x86/include/asm/syscall_wrapper.h
index 49d7e4970110..798a3c2bff4f 100644
--- a/arch/x86/include/asm/syscall_wrapper.h
+++ b/arch/x86/include/asm/syscall_wrapper.h
@@ -22,7 +22,7 @@
#ifdef CONFIG_IA32_EMULATION
/*
* For IA32 emulation, we need to handle "compat" syscalls *and* create
- * additional wrappers (aptly named __sys_ia32_sys_xyzzy) which decode the
+ * additional wrappers (aptly named __ia32_sys_xyzzy) which decode the
* ia32 regs in the proper order for shared or "common" syscalls. As some
* syscalls may not be implemented, we need to expand COND_SYSCALL in
* kernel/sys_ni.c and SYS_NI in kernel/time/posix-stubs.c to cover this
@@ -37,20 +37,20 @@
} \
#define SC_IA32_WRAPPERx(x, name, ...) \
- asmlinkage long __sys_ia32##name(const struct pt_regs *regs); \
- ALLOW_ERROR_INJECTION(__sys_ia32##name, ERRNO); \
- asmlinkage long __sys_ia32##name(const struct pt_regs *regs) \
+ asmlinkage long __ia32_sys##name(const struct pt_regs *regs); \
+ ALLOW_ERROR_INJECTION(__ia32_sys##name, ERRNO); \
+ asmlinkage long __ia32_sys##name(const struct pt_regs *regs) \
{ \
- return SyS##name(SC_IA32_REGS_TO_ARGS(x,__VA_ARGS__)); \
+ return __se_sys##name(SC_IA32_REGS_TO_ARGS(x,__VA_ARGS__));\
}
#define COND_SYSCALL(name) \
cond_syscall(sys_##name); \
- cond_syscall(__sys_ia32_##name)
+ cond_syscall(__ia32_sys_##name)
#define SYS_NI(name) \
SYSCALL_ALIAS(sys_##name, sys_ni_posix_timers); \
- SYSCALL_ALIAS(__sys_ia32_##name, sys_ni_posix_timers)
+ SYSCALL_ALIAS(__ia32_sys_##name, sys_ni_posix_timers)
#else /* CONFIG_IA32_EMULATION */
#define COMPAT_SC_IA32_STUBx(x, name, ...)
@@ -115,9 +115,10 @@
* Instead of the generic __SYSCALL_DEFINEx() definition, this macro takes
* struct pt_regs *regs as the only argument of the syscall stub named
* sys_*(). It decodes just the registers it needs and passes them on to
- * the SyS_*() wrapper and then to the SYSC_*() function doing the actual job.
- * These wrappers and functions are inlined, meaning that the assembly looks
- * as follows (slightly re-ordered):
+ * the __se_sys_*() wrapper performing sign extension and then to the
+ * __do_sys_*() function doing the actual job. These wrappers and functions
+ * are inlined (at least in very most cases), meaning that the assembly looks
+ * as follows (slightly re-ordered for better readability):
*
* <sys_recv>: <-- syscall with 4 parameters
* callq <__fentry__>
@@ -140,7 +141,7 @@
* the call chain.
*
* If IA32_EMULATION is enabled, this macro generates an additional wrapper
* named __sys_ia32_*() which decodes the struct pt_regs *regs according
* to the i386 calling convention (bx, cx, dx, si, di, bp).
*
* As the generic SYSCALL_DEFINE0() macro does not decode any parameters for
@@ -151,21 +152,21 @@
#define __SYSCALL_DEFINEx(x, name, ...) \
asmlinkage long sys##name(const struct pt_regs *regs); \
ALLOW_ERROR_INJECTION(sys##name, ERRNO); \
- static long SyS##name(__MAP(x,__SC_LONG,__VA_ARGS__)); \
- static inline long SYSC##name(__MAP(x,__SC_DECL,__VA_ARGS__)); \
+ static long __se_sys##name(__MAP(x,__SC_LONG,__VA_ARGS__)); \
+ static inline long __do_sys##name(__MAP(x,__SC_DECL,__VA_ARGS__));\
asmlinkage long sys##name(const struct pt_regs *regs) \
{ \
- return SyS##name(SC_X86_64_REGS_TO_ARGS(x,__VA_ARGS__));\
+ return __se_sys##name(SC_X86_64_REGS_TO_ARGS(x,__VA_ARGS__));\
} \
SC_IA32_WRAPPERx(x, name, __VA_ARGS__) \
- static long SyS##name(__MAP(x,__SC_LONG,__VA_ARGS__)) \
+ static long __se_sys##name(__MAP(x,__SC_LONG,__VA_ARGS__)) \
{ \
- long ret = SYSC##name(__MAP(x,__SC_CAST,__VA_ARGS__)); \
+ long ret = __do_sys##name(__MAP(x,__SC_CAST,__VA_ARGS__));\
__MAP(x,__SC_TEST,__VA_ARGS__); \
__PROTECT(x, ret,__MAP(x,__SC_ARGS,__VA_ARGS__)); \
return ret; \
} \
- static inline long SYSC##name(__MAP(x,__SC_DECL,__VA_ARGS__))
+ static inline long __do_sys##name(__MAP(x,__SC_DECL,__VA_ARGS__))
/*
* For VSYSCALLS, we need to declare these three syscalls with the new
@@ -140,7 +141,7 @@
*
* If IA32_EMULATION is enabled, this macro generates an additional wrapper
- * named __sys_ia32_*() which decodes the struct pt_regs *regs according
+ * named __ia32_sys_*() which decodes the struct pt_regs *regs according
* to the i386 calling convention (bx, cx, dx, si, di, bp).
*